@@ -121,6 +121,9 @@ class h5py_build_ext(build_ext):
         from Cython.Build import cythonize
         import numpy
 
+        complex256_support = hasattr(numpy, 'complex256') and \
+            os.environ.get('CIBW_ARCHS_MACOS') != 'arm64'
+
         # This allows ccache to recognise the files when pip builds in a temp
         # directory. It speeds up repeatedly running tests through tox with
         # ccache configured (CC="ccache gcc"). It should have no effect if
@@ -142,27 +145,20 @@ class h5py_build_ext(build_ext):
             api_gen.run()
 
         # Rewrite config.pxi file if needed
-        s = """\
+        s = f"""\
 # This file is automatically generated by the h5py setup script.  Don't modify.
 
-DEF MPI = %(mpi)s
-DEF ROS3 = %(ros3)s
-DEF HDF5_VERSION = %(version)s
+DEF MPI = {bool(config.mpi)}
+DEF ROS3 = {bool(config.ros3)}
+DEF HDF5_VERSION = {config.hdf5_version}
+DEF DIRECT_VFD = {bool(config.direct_vfd)}
 DEF SWMR_MIN_HDF5_VERSION = (1,9,178)
 DEF VDS_MIN_HDF5_VERSION = (1,9,233)
 DEF VOL_MIN_HDF5_VERSION = (1,11,5)
-DEF COMPLEX256_SUPPORT = %(complex256_support)s
-DEF NUMPY_BUILD_VERSION = '%(numpy_version)s'
-DEF CYTHON_BUILD_VERSION = '%(cython_version)s'
+DEF COMPLEX256_SUPPORT = {complex256_support}
+DEF NUMPY_BUILD_VERSION = '{numpy.__version__}'
+DEF CYTHON_BUILD_VERSION = '{cython_version}'
 """
-        s %= {
-            'mpi': bool(config.mpi),
-            'ros3': bool(config.ros3),
-            'version': config.hdf5_version,
-            'complex256_support': hasattr(numpy, 'complex256'),
-            'numpy_version': numpy.__version__,
-            'cython_version': cython_version,
-        }
         write_if_changed(config_file, s)
 
         # Run Cython
@@ -192,3 +188,4 @@ def write_if_changed(target_path, s: str):
         pass
 
     p.write_bytes(b)
+    print(f'Updated {p}')
