@@ -54,13 +54,15 @@ def mpi_enabled():
 
 
 class BuildConfig:
-    def __init__(self, hdf5_includedirs, hdf5_libdirs, hdf5_define_macros, hdf5_version, mpi, ros3):
+    def __init__(self, hdf5_includedirs, hdf5_libdirs, hdf5_define_macros,
+                 hdf5_version, mpi, ros3, direct_vfd):
         self.hdf5_includedirs = hdf5_includedirs
         self.hdf5_libdirs = hdf5_libdirs
         self.hdf5_define_macros = hdf5_define_macros
         self.hdf5_version = hdf5_version
         self.mpi = mpi
         self.ros3 = ros3
+        self.direct_vfd = direct_vfd
 
     @classmethod
     def from_env(cls):
@@ -68,17 +70,34 @@ class BuildConfig:
         h5_inc, h5_lib, h5_macros = cls._find_hdf5_compiler_settings(mpi)
 
         h5_version_s = os.environ.get('HDF5_VERSION')
+        h5py_ros3 = os.environ.get('H5PY_ROS3')
+        h5py_direct_vfd = os.environ.get('H5PY_DIRECT_VFD')
+
+        if h5_version_s and not mpi and h5py_ros3 and h5py_direct_vfd:
+            # if we know config, don't use wrapper, it may not be supported
+            return cls(
+                h5_inc, h5_lib, h5_macros, validate_version(h5_version_s), mpi,
+                h5py_ros3 == '1', h5py_direct_vfd == '1')
+
+        h5_wrapper = HDF5LibWrapper(h5_lib)
         if h5_version_s:
             h5_version = validate_version(h5_version_s)
-            h5_wrapper = HDF5LibWrapper(h5_lib)
         else:
-            h5_wrapper = HDF5LibWrapper(h5_lib)
             h5_version = h5_wrapper.autodetect_version()
             if mpi and not h5_wrapper.has_mpi_support():
                 raise RuntimeError("MPI support not detected")
-        ros3 = h5_wrapper.has_ros3_support()
 
-        return cls(h5_inc, h5_lib, h5_macros, h5_version, mpi, ros3)
+        if h5py_ros3:
+            ros3 = h5py_ros3 == '1'
+        else:
+            ros3 = h5_wrapper.has_ros3_support()
+
+        if h5py_direct_vfd:
+            direct_vfd = h5py_direct_vfd == '1'
+        else:
+            direct_vfd = h5_wrapper.has_direct_vfd_support()
+
+        return cls(h5_inc, h5_lib, h5_macros, h5_version, mpi, ros3, direct_vfd)
 
     @staticmethod
     def _find_hdf5_compiler_settings(mpi=False):
@@ -135,7 +154,9 @@ class BuildConfig:
             if os.name != 'nt':
                 print(
                     "Building h5py requires pkg-config unless the HDF5 path "
-                    "is explicitly specified", file=sys.stderr
+                    "is explicitly specified using the environment variable HDF5_DIR. "
+                    "For more information and details, "
+                    "see https://docs.h5py.org/en/stable/build.html#custom-installation", file=sys.stderr
                 )
                 raise
 
@@ -153,6 +174,7 @@ class BuildConfig:
             'hdf5_version': list(self.hdf5_version),  # list() to match the JSON
             'mpi': self.mpi,
             'ros3': self.ros3,
+            'direct_vfd': self.direct_vfd,
         }
 
     def changed(self):
@@ -175,6 +197,7 @@ class BuildConfig:
         print("     HDF5 Version:", repr(self.hdf5_version))
         print("      MPI Enabled:", self.mpi)
         print(" ROS3 VFD Enabled:", self.ros3)
+        print("DIRECT VFD Enabled:", self.direct_vfd)
         print(" Rebuild Required:", self.changed())
         print('')
         print('*' * 80)
@@ -200,14 +223,16 @@ class HDF5LibWrapper:
         if sys.platform.startswith('darwin'):
             default_path = 'libhdf5.dylib'
             regexp = re.compile(r'^libhdf5.dylib')
-        elif sys.platform.startswith('win') or \
-            sys.platform.startswith('cygwin'):
+        elif sys.platform.startswith('win'):
             default_path = 'hdf5.dll'
             regexp = re.compile(r'^hdf5.dll')
             if sys.version_info >= (3, 8):
                 # To overcome "difficulty" loading the library on windows
                 # https://bugs.python.org/issue42114
                 load_kw['winmode'] = 0
+        elif sys.platform.startswith('cygwin'):
+            default_path = 'cyghdf5-200.dll'
+            regexp = re.compile(r'^cyghdf5-\d+.dll$')
         else:
             default_path = 'libhdf5.so'
             regexp = re.compile(r'^libhdf5.so')
@@ -281,3 +306,6 @@ class HDF5LibWrapper:
 
     def has_ros3_support(self):
         return self.has_functions("H5Pget_fapl_ros3", "H5Pset_fapl_ros3")
+
+    def has_direct_vfd_support(self):
+        return self.has_functions("H5Pget_fapl_direct", "H5Pset_fapl_direct")
